@@ -3,7 +3,7 @@ RGEOSMiscFunc = function(spgeom, byid, func) {
      warning("Spatial object is not projected; GEOS expects planar coordinates")
     byid = as.logical(byid)
     if (is.na(byid)) stop("Invalid value for byid, must be logical")
-    if (inherits(spgeom, "SpatialPolygons") && get_do_poly_check()) 
+    if (inherits(spgeom, "SpatialPolygons") && get_do_poly_check() && notAllComments(spgeom)) 
         spgeom <- createSPComment(spgeom)
     
     x <- .Call(func, .RGEOS_HANDLE, spgeom, byid, PACKAGE="rgeos")
